@@ -1,6 +1,7 @@
 # type: ignore
 
 import pytest
+import slotted
 from tippo import GenericMeta
 
 import basicco
@@ -23,5 +24,12 @@ def test_bases():
     assert basicco.SlottedBase()
 
 
+def test_slotted_mixed():
+    class Mixed(basicco.SlottedBase, slotted.SlottedMapping):  # noqa
+        pass
+
+    assert Mixed
+
+
 if __name__ == "__main__":
     pytest.main()
