@@ -1,4 +1,6 @@
-import pytest  # noqa
+# type: ignore
+
+import pytest
 
 from basicco.safe_repr import safe_repr
 
@@ -11,7 +13,9 @@ def test_safe_repr():
 
     obj = Class()
     standard_repr = object.__repr__(obj)
-    assert repr(obj) == standard_repr[:-1] + "; repr failed due to 'RuntimeError: oh oh'>"
+    assert (
+        repr(obj) == standard_repr[:-1] + "; repr failed due to 'RuntimeError: oh oh'>"
+    )
 
 
 if __name__ == "__main__":
